@@ -1,5 +1,7 @@
 ## ----include=FALSE-------------------------------------------------------
 knitr::opts_chunk$set(comment="")
+if(grepl("windows", tolower(Sys.info()[["sysname"]])))
+  knitr::opts_chunk$set(comment="", error =TRUE)
 
 ## ----gh-installation, eval = FALSE---------------------------------------
 #  # install.packages("devtools")
